#include "../iphone/minimal.h"

extern int iSoundMuted;
extern int linesInterlace_user;

void hildon_init(int *argc, char ***argv,char *fl,char* lst);
